//module pattern to prevent global namespace polution
var CommentExample = (function(CommentExample, $, undefined){

    //functions passed directly into $ will run when the document is ready to be manipulated
    $(function(){
        
        //cache jquery objects that you'll get multiple times
        var comments = $("#comments");
        var commentForm = $("#comment-form");
        var nameField = $("#name-field");
        var commentField = $("#comment-field"); 
        
        //Load in all the pre-existing comments from the server, and add them to the document
        $.getJSON("comments.json",function(data){
            var records = data.comments;
            for(var i=0; i<records.length; i++){
                var record = records[i];
                comments.append(makeComment(record.name, record.comment));
            }
        });
        
        //Submit a comment
        commentForm.on("submit",function(){
            
            //build up an object to submit
            var data = {
                name: nameField.val(),
                comment: commentField.val()
            }
            
            //add a new comment
            var newComment = makeComment(data.name, data.comment);
            newComment.hide();
            
            comments.append(newComment);
            
            newComment.fadeIn();
            
            //POST to the server
            $.ajax({
                url: commentForm.attr("action"),
                type: "POST",
                data: data,
                error:function(){
                    //oh no! Something went wrong!
                    newComment.append($("<div class='failed'>Sorry, your comment could not be submitted!</div>"));
                }
            });
            
            //clear the fields
            nameField.val("");
            commentField.val("");
            
            return false;
        });
        
    });
    
    //utility function for making a comment
    function makeComment(name, comment){
        var newComment = $("<div>").addClass("comment").addClass("well");
            
        var nameDiv = $("<div>").addClass("comment-name");
        nameDiv.text(name);
        
        var bodyDiv = $("<div>").addClass("comment-body");
        bodyDiv.text(comment);
        
        newComment.append(nameDiv).append(bodyDiv);
        
        return newComment;
    }


    return CommentExample;
})(CommentExample || {}, window.jQuery);
